@@ -31,11 +31,11 @@ class APIFunction(LambdaFunction):
         elif method == "put":
             response = self.put(event, context, *args)
 
+        elif method == "delete":
+            response = self.delete(event, context, *args)
+
         elif method == "options":
-            print("Returning options payload:")
             response = self.create_return()
-            print(response)
-            print(event)
 
         else:
             raise Exception(f"Triggered with unexpected HTTP method {method}.")
@@ -72,6 +72,11 @@ class APIFunction(LambdaFunction):
         if callable(put):
             methods.append("PUT")
 
+        # Check delete metho
+        delete = getattr(self, "delete", None)
+        if callable(delete):
+            methods.append("DELETE")
+
         return methods
 
     def _get_url_params(self):
